@@ -28,6 +28,7 @@
 
 #include <vector>
 #include "defs.h"
+
 class BSONObj;
 
 class BSONArrayObj {
@@ -36,15 +37,15 @@ public:
 	~BSONArrayObj();
 	BSONArrayObj(const BSONArrayObj& orig);
 
-	__int32 length() const;
+	virtual __int32 length() const;
 	void add(const BSONObj& obj);
-	BSONObj* get(__int32 index) const;
-   char* toChar() const;
+	virtual BSONObj* get(__int32 index) const;
+   virtual char* toChar() const;
 	typedef std::vector<BSONObj*>::iterator iterator;
-	BSONArrayObj* select(const char* select) const;
+	virtual BSONArrayObj* select(const char* select) const;
 	
-	iterator begin();
-	iterator end();
+	virtual iterator begin();
+	virtual iterator end();
 
 private:
 	std::vector<BSONObj*> _elements;
